pub fn satisfies(clauses: &[HornClause], assignment: &[bool]) -> boolExpand description
Re-check a satisfying model: every clause holds (a rule with a true body has a true head; a goal has a false body).
pub fn satisfies(clauses: &[HornClause], assignment: &[bool]) -> boolRe-check a satisfying model: every clause holds (a rule with a true body has a true head; a goal has a false body).